##################################################################################
#                       Auto-generated Metaflow stub file                        #
# MF version: 2.12.8                                                             #
# Generated on 2024-07-16T15:51:55.380373                                        #
##################################################################################

from __future__ import annotations

import typing
if typing.TYPE_CHECKING:
    import metaflow.procpoll

class ProcPollEvent(object, metaclass=type):
    def __init__(self, fd, can_read = False, is_terminated = False):
        ...
    ...

class ProcPoll(object, metaclass=type):
    def poll(self):
        ...
    def add(self, fd):
        ...
    def remove(self, fd):
        ...
    ...

class LinuxProcPoll(ProcPoll, metaclass=type):
    def __init__(self):
        ...
    def add(self, fd):
        ...
    def remove(self, fd):
        ...
    def poll(self, timeout):
        ...
    ...

class DarwinProcPoll(ProcPoll, metaclass=type):
    def __init__(self):
        ...
    def add(self, fd):
        ...
    def remove(self, fd):
        ...
    def poll(self, timeout):
        ...
    ...

def make_poll():
    ...

